Class: Google::Apis::CloudschedulerV1beta1::OAuthToken
- Inherits:
-
Object
- Object
- Google::Apis::CloudschedulerV1beta1::OAuthToken
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudscheduler_v1beta1/classes.rb,
lib/google/apis/cloudscheduler_v1beta1/representations.rb,
lib/google/apis/cloudscheduler_v1beta1/representations.rb
Overview
Contains information needed for generating an OAuth token. This type of authorization should generally only be used when calling Google APIs hosted on *.googleapis.com.
Instance Attribute Summary collapse
-
#scope ⇒ String
OAuth scope to be used for generating OAuth access token.
-
#service_account_email ⇒ String
Service account email to be used for generating OAuth token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OAuthToken
constructor
A new instance of OAuthToken.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OAuthToken
Returns a new instance of OAuthToken.
625 626 627 |
# File 'lib/google/apis/cloudscheduler_v1beta1/classes.rb', line 625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#scope ⇒ String
OAuth scope to be used for generating OAuth access token. If not specified, "
https://www.googleapis.com/auth/cloud-platform" will be used.
Corresponds to the JSON property scope
615 616 617 |
# File 'lib/google/apis/cloudscheduler_v1beta1/classes.rb', line 615 def scope @scope end |
#service_account_email ⇒ String
Service account email to
be used for generating OAuth token. The service account must be within the
same project as the job. The caller must have iam.serviceAccounts.actAs
permission for the service account.
Corresponds to the JSON property serviceAccountEmail
623 624 625 |
# File 'lib/google/apis/cloudscheduler_v1beta1/classes.rb', line 623 def service_account_email @service_account_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
630 631 632 633 |
# File 'lib/google/apis/cloudscheduler_v1beta1/classes.rb', line 630 def update!(**args) @scope = args[:scope] if args.key?(:scope) @service_account_email = args[:service_account_email] if args.key?(:service_account_email) end |