Class: Google::Apis::CloudschedulerV1beta1::HttpTarget
- Inherits:
-
Object
- Object
- Google::Apis::CloudschedulerV1beta1::HttpTarget
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudscheduler_v1beta1/classes.rb,
lib/google/apis/cloudscheduler_v1beta1/representations.rb,
lib/google/apis/cloudscheduler_v1beta1/representations.rb
Overview
Http target. The job will be pushed to the job handler by means of an HTTP request via an http_method such as HTTP POST, HTTP GET, etc. The job is acknowledged by means of an HTTP response code in the range [200 - 299]. A failure to receive a response constitutes a failed execution. For a redirected request, the response returned by the redirected request is considered.
Instance Attribute Summary collapse
-
#body ⇒ String
HTTP request body.
-
#headers ⇒ Hash<String,String>
HTTP request headers.
-
#http_method ⇒ String
Which HTTP method to use for the request.
-
#oauth_token ⇒ Google::Apis::CloudschedulerV1beta1::OAuthToken
Contains information needed for generating an OAuth token.
-
#oidc_token ⇒ Google::Apis::CloudschedulerV1beta1::OidcToken
Contains information needed for generating an OpenID Connect token.
-
#uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpTarget
constructor
A new instance of HttpTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpTarget
Returns a new instance of HttpTarget.
284 285 286 |
# File 'lib/google/apis/cloudscheduler_v1beta1/classes.rb', line 284 def initialize(**args) update!(**args) end |
Instance Attribute Details
#body ⇒ String
HTTP request body. A request body is allowed only if the HTTP method is POST,
PUT, or PATCH. It is an error to set body on a job with an incompatible
HttpMethod.
Corresponds to the JSON property body
NOTE: Values are automatically base64 encoded/decoded in the client library.
225 226 227 |
# File 'lib/google/apis/cloudscheduler_v1beta1/classes.rb', line 225 def body @body end |
#headers ⇒ Hash<String,String>
HTTP request headers. This map contains the header field names and values. The
user can specify HTTP request headers to send with the job's HTTP request.
Repeated headers are not supported, but a header value can contain commas. The
following headers represent a subset of the headers that accompany the job's
HTTP request. Some HTTP request headers are ignored or replaced. A partial
list of headers that are ignored or replaced is below: * Host: This will be
computed by Cloud Scheduler and derived from uri. * Content-Length: This
will be computed by Cloud Scheduler. * User-Agent: This will be set to "
Google-Cloud-Scheduler". * X-Google-*: Used internally by Google. If
present in an external user request, it is replaced by the internal header. *
X-AppEngine-*: Used internally by Google. If present in an external user
request, it is replaced by the internal header. * X-CloudScheduler: This
header will be set to true. * X-CloudScheduler-JobName: This header will
contain the job name. * X-CloudScheduler-ScheduleTime: For Cloud Scheduler
jobs specified in the unix-cron format, this header will contain the job
schedule as an offset of UTC parsed according to RFC3339. Remains constant
across retries and can be used for job request deduplication. If the job has a
body and the following headers are not set by the user, Cloud Scheduler sets
default values: * Content-Type: This will be set to "application/octet-
stream". You can override this default by explicitly setting Content-Type
to a particular media type when creating the job. For example, you can set
Content-Type to "application/json". The total size of headers must be less
than 80KB.
Corresponds to the JSON property headers
253 254 255 |
# File 'lib/google/apis/cloudscheduler_v1beta1/classes.rb', line 253 def headers @headers end |
#http_method ⇒ String
Which HTTP method to use for the request.
Corresponds to the JSON property httpMethod
258 259 260 |
# File 'lib/google/apis/cloudscheduler_v1beta1/classes.rb', line 258 def http_method @http_method end |
#oauth_token ⇒ Google::Apis::CloudschedulerV1beta1::OAuthToken
Contains information needed for generating an OAuth token. This type of authorization should
generally only be used when calling Google APIs hosted on *.googleapis.com.
Corresponds to the JSON property oauthToken
265 266 267 |
# File 'lib/google/apis/cloudscheduler_v1beta1/classes.rb', line 265 def oauth_token @oauth_token end |
#oidc_token ⇒ Google::Apis::CloudschedulerV1beta1::OidcToken
Contains information needed for generating an OpenID Connect token. This type of
authorization can be used for many scenarios, including calling Cloud Run, or
endpoints where you intend to validate the token yourself.
Corresponds to the JSON property oidcToken
273 274 275 |
# File 'lib/google/apis/cloudscheduler_v1beta1/classes.rb', line 273 def oidc_token @oidc_token end |
#uri ⇒ String
Required. The full URI path that the request will be sent to. This string must
begin with either "http://" or "https://". Some examples of valid values for
uri are: http://acme.com and https://acme.com/sales:8080. Cloud Scheduler
will encode some characters for safety and compatibility. The maximum allowed
URL length is 2083 characters after encoding.
Corresponds to the JSON property uri
282 283 284 |
# File 'lib/google/apis/cloudscheduler_v1beta1/classes.rb', line 282 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
289 290 291 292 293 294 295 296 |
# File 'lib/google/apis/cloudscheduler_v1beta1/classes.rb', line 289 def update!(**args) @body = args[:body] if args.key?(:body) @headers = args[:headers] if args.key?(:headers) @http_method = args[:http_method] if args.key?(:http_method) @oauth_token = args[:oauth_token] if args.key?(:oauth_token) @oidc_token = args[:oidc_token] if args.key?(:oidc_token) @uri = args[:uri] if args.key?(:uri) end |